@@ -11,13 +11,14 @@ from abc import abstractmethod, ABCMeta
 from sumoappclient.omnistorage.factory import ProviderFactory
 from sumoapputils.common.utils import EXCLUDED_APPS_WITHOUT_SC_PARAMS, get_test_logger, slugify
 
+logger = get_test_logger()
 
 try:
     from sumoapputils.appdev.appdeployapi import push_app_api, push_app_api_v2
-except ImportError:
-    raise Exception("push_app_api, push_app_api_v2 functions are not available")
+except (ImportError, ModuleNotFoundError) as e:
+    logger.info("push_app_api, push_app_api_v2 functions are not available")
+
 
-logger = get_test_logger()
 
 
 @six.add_metaclass(ABCMeta)
