@@ -17,7 +17,19 @@ ALL_APPS_FILENAME = "full_app_list.txt"
 PUSH_SCRIPT_FILENAME = "push_new_sumo_app.bash"
 EXCLUDED_APP_PREFIXES = ("PCI/PCIv2", "SecurityApp", "//")
 EXCLUDED_MODULE_LOGGING = ("requests", "urllib3")
-EXCLUDED_APPS_WITHOUT_SC_PARAMS = ("Global Intelligence for Amazon GuardDuty", )
+EXCLUDED_APPS_WITHOUT_SC_PARAMS = (
+    "Global Intelligence for Amazon GuardDuty",
+    "Data Volume",
+    "Data Volume - V2",
+    "Audit",
+    "Artifactory",
+    "Enterprise Audit - Collector & Data Forwarding Management",
+    "Enterprise Audit - Content Management",
+    "Enterprise Audit - Security Management",
+    "Enterprise Audit - User & Role Management",
+    "Global Intelligence for CloudTrail DevOps",
+    "Global Intelligence for AWS CloudTrail SecOps",
+)
 
 
 def get_content_directory_from_wd():
@@ -26,15 +38,18 @@ def get_content_directory_from_wd():
     work_dir = os.path.join(work_dir, "content")
     return work_dir
 
+
 class ENVIRONMENT:
     CONTENT_DIR = os.getenv("CONTENT_DIR", get_content_directory_from_wd())
     SUMO_APP_UTILS_MODE = os.getenv("SUMO_APP_UTILS_MODE", "PARTNER")
-    SUMO_DEPLOYMENT =  os.getenv("SUMO_DEPLOYMENT")
+    SUMO_DEPLOYMENT = os.getenv("SUMO_DEPLOYMENT")
+
 
 def get_content_dirpath():
     content_dirpath = ENVIRONMENT.CONTENT_DIR
     return get_normalized_path(content_dirpath)
 
+
 def get_file_data(filepath):
     data = None
     with open(filepath) as fp:
@@ -55,6 +70,7 @@ class USER(object):
 
 USER = USER()
 
+
 def touch(path):
     with open(path, 'a'):
         os.utime(path, None)
@@ -66,6 +82,7 @@ def get_test_log_dir():
         os.mkdir(log_dir)
     return log_dir
 
+
 def get_test_log_file_name():
 
     BUILD_NUMBER = os.environ.get("BUILD_NUMBER", "UNKNOWN")
@@ -136,5 +153,6 @@ def delete_batch_files_in_s3(bucket_name, region, prefix=""):
     bucket = s3.Bucket(bucket_name)
     bucket.objects.filter(Prefix=prefix).delete()
 
+
 def slugify(text):
-    return re.sub(' +', '-',text.strip().lower())
\ No newline at end of file
+    return re.sub(' +', '-',text.strip().lower())
